==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/INSTALLATIONCODEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INSTALLATIONCODEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INSTALLATIONCODEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="INSTALLATIONCODE" type="{http://schemas.datastream.net/MP_fields}CODE8_Type"/>
 *         &lt;element name="INSTALLATIONCODEDESCRIPTION" type="{http://schemas.datastream.net/MP_fields}CODE750_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="entity" type="{http://schemas.datastream.net/MP_fields}MPENTITY_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSTALLATIONCODEID_Type", propOrder = {
    "installationcode",
    "installationcodedescription"
})
public class INSTALLATIONCODEID_Type {

    @XmlElement(name = "INSTALLATIONCODE", required = true)
    protected String installationcode;
    @XmlElement(name = "INSTALLATIONCODEDESCRIPTION")
    protected String installationcodedescription;
    @XmlAttribute(name = "entity")
    protected NOUN_Type entity;

    /**
     * Obtient la valeur de la propriété installationcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSTALLATIONCODE() {
        return installationcode;
    }

    /**
     * Définit la valeur de la propriété installationcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSTALLATIONCODE(String value) {
        this.installationcode = value;
    }

    /**
     * Obtient la valeur de la propriété installationcodedescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSTALLATIONCODEDESCRIPTION() {
        return installationcodedescription;
    }

    /**
     * Définit la valeur de la propriété installationcodedescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSTALLATIONCODEDESCRIPTION(String value) {
        this.installationcodedescription = value;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getEntity() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setEntity(NOUN_Type value) {
        this.entity = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/INSTALLATIONCODEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INSTALLATIONCODEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INSTALLATIONCODEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="INSTALLATIONCODE" type="{http://schemas.datastream.net/MP_fields}CODE8_Type"/>
 *         &lt;element name="INSTALLATIONCODEDESCRIPTION" type="{http://schemas.datastream.net/MP_fields}CODE750_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="entity" type="{http://schemas.datastream.net/MP_fields}MPENTITY_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INSTALLATIONCODEID_Type", propOrder = {
    "installationcode",
    "installationcodedescription"
})
public class INSTALLATIONCODEID_Type {

    @XmlElement(name = "INSTALLATIONCODE", required = true)
    protected String installationcode;
    @XmlElement(name = "INSTALLATIONCODEDESCRIPTION")
    protected String installationcodedescription;
    @XmlAttribute(name = "entity")
    protected NOUN_Type entity;

    /**
     * Gets the value of the installationcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSTALLATIONCODE() {
        return installationcode;
    }

    /**
     * Sets the value of the installationcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSTALLATIONCODE(String value) {
        this.installationcode = value;
    }

    /**
     * Gets the value of the installationcodedescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSTALLATIONCODEDESCRIPTION() {
        return installationcodedescription;
    }

    /**
     * Sets the value of the installationcodedescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSTALLATIONCODEDESCRIPTION(String value) {
        this.installationcodedescription = value;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getEntity() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setEntity(NOUN_Type value) {
        this.entity = value;
    }

}
